@@ -20,20 +20,24 @@ package Net::BitTorrent;
     use Net::BitTorrent::DHT;
     use Net::BitTorrent::Version;
     use version qw[qv];
-    our $SVN = q[$Id: BitTorrent.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 2; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 49 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
-    my (@CONTENTS)
-        = \my (%_tcp,                  %_udp,
-               %_schedule,             %_tid,
-               %_event,                %_torrents,
-               %_connections,          %_peerid,
-               %_max_ul_rate,          %_k_ul,
-               %_max_dl_rate,          %_k_dl,
-               %_dht,                  %_use_dht,
-               %__UDP_OBJECT_CACHE,    %_peers_per_torrent,
-               %_connections_per_host, %_half_open
-        );
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
+    my (@CONTENTS) = \my (
+        %_tcp,                  %_udp,
+        %_schedule,             %_tid,
+        %_event,                %torrents,
+        %_connections,          %peerid,
+        %_max_ul_rate,          %_k_ul,
+        %_max_dl_rate,          %_k_dl,
+        %_dht,                  %_use_dht,
+        %__UDP_OBJECT_CACHE,    %_peers_per_torrent,
+        %_connections_per_host, %_half_open,
+        #############################################################
+        %_encryption_mode
+    );
     my %REGISTRY;
+    sub _MSE_DISABLED {0}
+    sub _MSE_ENABLED  {1}
+    sub _MSE_FORCED   {2}
 
     sub new {
         my ($class, $args) = @_;
@@ -47,16 +51,17 @@ package Net::BitTorrent;
         $_k_dl{refaddr $self}                 = 0;
         $_peers_per_torrent{refaddr $self}    = 100;
         $_half_open{refaddr $self}            = 8;
-        $_connections_per_host{refaddr $self} = 2;
-        $_torrents{refaddr $self}             = {};
+        $_connections_per_host{refaddr $self} = 1;
+        $torrents{refaddr $self}              = {};
         $_tid{refaddr $self}                  = qq[\0] x 5;
         $_use_dht{refaddr $self}              = 1;
+        $_encryption_mode{refaddr $self}      = _MSE_ENABLED;
 
         # Internals
         $_connections{refaddr $self} = {};
         $_schedule{refaddr $self}    = {};
-        $_dht{refaddr $self} = Net::BitTorrent::DHT->new({Client => $self});
-        $_peerid{refaddr $self} = Net::BitTorrent::Version::gen_peerid();
+        $_dht{refaddr $self}   = Net::BitTorrent::DHT->new({Client => $self});
+        $peerid{refaddr $self} = Net::BitTorrent::Version::gen_peerid();
         if (defined $args) {
             if (ref($args) ne q[HASH]) {
                 carp q[Net::BitTorrent->new({}) requires ]
@@ -84,7 +89,7 @@ package Net::BitTorrent;
         # Clear everything just in case
         $self->_reset_bandwidth;
         weaken($REGISTRY{refaddr $self} = $self);
-        $$self = $_peerid{refaddr $self};
+        $$self = $peerid{refaddr $self};
         return $self;
     }
 
@@ -139,7 +144,26 @@ package Net::BitTorrent;
         return inet_ntoa($packed_ip);
     }
 
+    sub _encryption_mode {
+        my ($self) = @_;
+        return $_encryption_mode{refaddr $self};
+    }
+
     # Setters | Private
+    sub _set_encryption_mode {
+        my ($self, $value) = @_;
+        if (not defined $value
+            or (    ($value != _MSE_DISABLED)
+                and ($value != _MSE_ENABLED)
+                and ($value != _MSE_FORCED))
+            )
+        {   carp
+                q[Net::BitTorrent->_set_encryption_mode( VALUE ) requires an integer value];
+            return;
+        }
+        return $_encryption_mode{refaddr $self} = $value;
+    }
+
     sub _set_max_ul_rate {    # BYTES per second
         my ($self, $value) = @_;
         if (not defined $value or $value !~ m[^\d+$] or !$value) {
@@ -201,8 +225,8 @@ package Net::BitTorrent;
     }
 
     # Accessors | Public
-    sub peerid   { my ($self) = @_; return $_peerid{refaddr $self} }
-    sub torrents { my ($self) = @_; return $_torrents{refaddr $self} }
+    sub peerid   { my ($self) = @_; return $peerid{refaddr $self} }
+    sub torrents { my ($self) = @_; return $torrents{refaddr $self} }
 
     # Methods | Public
     sub do_one_loop {
@@ -432,7 +456,7 @@ package Net::BitTorrent;
                     if (scalar(
                             grep {
                                 $_->{q[Object]}->isa(q[Net::BitTorrent::Peer])
-                                    && !$_->{q[Object]}->_torrent
+                                    && !$_->{q[Object]}->torrent
                                 } values %{$_connections{refaddr $self}}
                         ) < $_half_open{refaddr $self}
                         )
@@ -461,7 +485,7 @@ package Net::BitTorrent;
                         next POPSOCK;
                     }
                     else {
-                        for my $_tor (values %{$_torrents{refaddr $self}}) {
+                        for my $_tor (values %{$torrents{refaddr $self}}) {
                             for my $_tier (@{$_tor->trackers}) {
                                 my ($tracker) = grep {
                                     $_->isa(
@@ -534,8 +558,8 @@ package Net::BitTorrent;
         carp q[Bad infohash for Net::BitTorrent->_locate_torrent(INFOHASH)]
             && return
             if $infohash !~ m[^[\d|a-f]{40}$]i;
-        return $_torrents{refaddr $self}{lc $infohash}
-            ? $_torrents{refaddr $self}{lc $infohash}
+        return $torrents{refaddr $self}{lc $infohash}
+            ? $torrents{refaddr $self}{lc $infohash}
             : undef;
     }
 
@@ -551,7 +575,7 @@ package Net::BitTorrent;
         my $torrent = Net::BitTorrent::Torrent->new($args);
         return if not defined $torrent;
         return if $self->_locate_torrent($torrent->infohash);
-        return $_torrents{refaddr $self}{$torrent->infohash} = $torrent;
+        return $torrents{refaddr $self}{$torrent->infohash} = $torrent;
     }
 
     sub remove_torrent {
@@ -567,7 +591,7 @@ package Net::BitTorrent;
                               q[Removing .torrent torrent from local client]);
         }
         $torrent->stop;    # XXX - Should this be here?
-        return delete $_torrents{refaddr $self}{$torrent->infohash};
+        return delete $torrents{refaddr $self}{$torrent->infohash};
     }
 
     # Methods | Public | Callback system
@@ -621,9 +645,9 @@ package Net::BitTorrent;
                 q[Net::BitTorrent->_schedule() requires a blessed 'Object' parameter];
             return;
         }
-        if ((!$args->{q[Time]}) || ($args->{q[Time]} !~ m[^\d+$])) {
+        if ((!$args->{q[Time]}) || ($args->{q[Time]} !~ m[^\d+(?:\.\d+)?$])) {
             carp
-                q[Net::BitTorrent->_schedule() requires an integer 'Time' parameter];
+                q[Net::BitTorrent->_schedule() requires an integer or float 'Time' parameter];
             return;
         }
         if ((!$args->{q[Code]}) || (ref $args->{q[Code]} ne q[CODE])) {
@@ -697,7 +721,7 @@ package Net::BitTorrent;
     sub as_string {
         my ($self, $advanced) = @_;
         my $dump
-            = !$advanced ? $_peerid{refaddr $self} : sprintf <<'END',
+            = !$advanced ? $peerid{refaddr $self} : sprintf <<'END',
 Net::BitTorrent
 
 Peer ID: %s
@@ -709,17 +733,16 @@ Torrents in queue: %d
 %s
 ----------
 END
-            $_peerid{refaddr $self},
+            $peerid{refaddr $self},
             $_use_dht{refaddr $self} ? q[En] : q[Dis],
             unpack(q[H*], $_dht{refaddr $self}->node_id),
             $self->_tcp_host, $self->_tcp_port, $self->_udp_host,
-            $self->_udp_port,
-            (scalar keys %{$_torrents{refaddr $self}}), join(
+            $self->_udp_port, (scalar keys %{$torrents{refaddr $self}}), join(
             qq[\r\n],
             map {
                 sprintf q[%40s (%d: %s)], $_->infohash, $_->status,
                     $_->_status_as_string()
-                } values %{$_torrents{refaddr $self}}
+                } values %{$torrents{refaddr $self}}
             );
         return defined wantarray ? $dump : print STDERR qq[$dump\n];
     }
@@ -757,19 +780,6 @@ END
 
 Net::BitTorrent - BitTorrent peer-to-peer protocol class
 
-=head1 NOTICE
-
-=for html <span style="color: #F00; font-size: 1.5em;">
-
-THIS PROJECT IS ACTIVELY SEEKING DEVELOPERS. Ahem, I hate to shout but
-N::B could really use a second or third pair of eyes over the next few
-versions.  So, if you're interested and have cryptographic experience,
-or you're just familiar with Perl and want to chip in, see the notes
-on L<Joining the Project|Net::BitTorrent::Notes/"Joining the Project">
-and L<let me know|/"Author">.
-
-=for html </span>
-
 =head1 Synopsis
 
   use Net::BitTorrent;
@@ -1325,7 +1335,8 @@ contains the following keys:
 
 =item C<Torrent>
 
-The L<Net::BitTorrent::Torrent> object related to this event.
+The L<Net::BitTorrent::Torrent|Net::BitTorrent::Torrent> object related
+to this event.
 
 =item C<Index>
 
@@ -1352,33 +1363,10 @@ L<Net::BitTorrent::Notes|Net::BitTorrent::Notes> if you've found one.
 
 =head1 Notes
 
-=head2 Support and Availability
+=head2 Support Links
 
-Visit the following for support and information related to
-L<Net::BitTorrent|Net::BitTorrent>:
-
-=over 4
-
-=item The project's website
-
-For SVN info, please visit the project's home:
-http://sankorobinson.com/net-bittorrent/.
-
-=item Bug and Issue Tracker
-
-Use http://code.google.com/p/net-bittorrent/issues/list for bug
-tracking.
-
-Before sending a report, make sure the bug is reproducible.  If the
-problem requires a specific .torrent file, the issue tracker allows
-attachments.  Make sure you are using the a recent release of
-L<Net::BitTorrent|Net::BitTorrent>.  This may mean checking out the latest
-SVN commit.
-
-=back
-
-See L<Net::BitTorrent::Notes|Net::BitTorrent::Notes/"See Also">
-for links to a mailing list, SVN information, and more.
+Please refer to
+L<Net::BitTorrent::Notes|Net::BitTorrent::Notes/"Support and Information Links for C<Net::BitTorrent>">.
 
 =head2 Dependencies
 
@@ -1387,31 +1375,6 @@ L<Digest::SHA|Digest::SHA> to function and relies upon
 L<Module::Build|Module::Build> for installation.  As of perl 5.10, these
 are all CORE modules; they come bundled with the distribution.
 
-=head2 Development Policy
-
-=over 4
-
-=item * B<All APIs are subject to change.>
-
-Changes to documented or well established parts will be clearly listed
-and archived in the F<CHANGES> file.
-
-Functions and parameters that are all_lower_case_and_contain_underscores
-are typically experimental and have a very good chance of being
-depreciated in a future version.
-
-=item * B<All undocumented functionality is subject to change without notice.>
-
-L<Net::BitTorrent|Net::BitTorrent> is just asploding with incomplete bits
-of stuff so I reserve the right to change or eliminate code at any time
-without warning I<unless> functionality is defined in POD documentation.
-
-If you sift through the source and find something nifty that isn't
-described I<in full> in POD, don't expect your client to work with future
-releases.
-
-=back
-
 =head2 Examples
 
 For a demonstration of L<Net::BitTorrent|Net::BitTorrent>, see
@@ -1440,7 +1403,7 @@ decide what to do with it.
 
 L Rotger
 
-#bittorrent on Freenode for letting me idle.
+C<#bittorrent> on Freenode for letting me idle.
 
 Michel Valdrighi for b2
 
@@ -1452,7 +1415,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -1468,6 +1431,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: BitTorrent.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $
+=for svn $Id: BitTorrent.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
 
 =cut
