@@ -7,8 +7,7 @@ package Net::BitTorrent::Protocol;
     use lib q[../../../lib];
     use Net::BitTorrent::Util qw[:bencode];
     use version qw[qv];
-    our $SVN = q[$Id: Protocol.pm 48 2009-01-02 17:39:49Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 1; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 48 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
     use vars qw[@EXPORT_OK %EXPORT_TAGS];
     use Exporter qw[];
     *import = *import = *Exporter::import;
@@ -55,6 +54,9 @@ package Net::BitTorrent::Protocol;
                 _build_dht_reply_ping      _build_dht_query_ping
                 _build_dht_reply_find_node _build_dht_query_find_node]
         ],
+
+        # XXX - Move MSE-related functions from N::B::Peer
+        #mse => [qw[  ]]
     );
     sub HANDSHAKE      {-1}
     sub KEEPALIVE      {q[]}
@@ -963,7 +965,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -979,6 +981,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Protocol.pm 48 2009-01-02 17:39:49Z sanko@cpan.org $
+=for svn $Id: Protocol.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
 
 =cut
