@@ -7,8 +7,7 @@ package Net::BitTorrent::Torrent::File;
     use Scalar::Util qw[blessed weaken refaddr];
     use Fcntl qw[/O_/ /SEEK/ :flock];
     use version qw[qv];
-    our $SVN = q[$Id: File.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 42 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
     my (@CONTENTS)
         = \
         my (%path, %torrent, %size, %index, %priority, %mode, %handle,
@@ -79,11 +78,33 @@ package Net::BitTorrent::Torrent::File;
     sub index   { return $index{refaddr +shift} }
     sub path    { return $path{refaddr +shift} }
 
-    # Methods | private
+    # Accessors | Private
+    sub _percent_complete {
+        my ($self) = @_;
+        my $start = 0;
+        for my $index (0 .. $index{refaddr $self} - 1) {
+            $start += $torrent{refaddr $self}->files->[$index]->size;
+        }
+        my $end          = $start + $size{refaddr $self};
+        my $piece_length = $torrent{refaddr $self}->raw_data(1)
+            ->{q[info]}{q[piece length]};
+        my $have      = 0;
+        my $_bitfield = $torrent{refaddr +shift}->bitfield;
+        $start = int($start / $piece_length);
+        $end   = int(($end / $piece_length) + 1);
+        for my $index ($start .. $end) {
+            $have += vec($_bitfield, $index, 1);
+        }
+        my $return = ($have / ($end - $start) * 100);
+        return $return > 100 ? 100 : $return;
+    }
+
+    # Methods | Private
     sub _open {
         my ($self, $mode) = @_;
         if ((!$mode) || ($mode !~ m[^[rw]$])) {
-            carp q[Net::BitTorrent::Torrent::File->_open() requires a mode];
+            carp
+                q[Net::BitTorrent::Torrent::File->_open() requires a valid mode];
             return;
         }
         if (defined $handle{refaddr $self} and defined $mode{refaddr $self}) {
@@ -529,6 +550,7 @@ Path: %s
 Size: %d bytes
 Priority: %d
 Open mode: %s
+Complete: %3.2f%%
 
 Torrent: %s
 Index: %d of %d
@@ -541,6 +563,7 @@ END
              : $mode{refaddr $self} eq q[rw] ? q[Read/Write]
              : q[Closed]
             ),
+            $self->_percent_complete,
             $torrent{refaddr $self}->infohash, $index{refaddr $self},
             scalar(@{$torrent{refaddr $self}->files});
         return defined wantarray ? $dump : print STDERR qq[$dump\n];
@@ -659,7 +682,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -675,6 +698,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: File.pm 42 2008-12-05 04:54:43Z sanko@cpan.org $
+=for svn $Id: File.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
 
 =cut
