@@ -10,8 +10,7 @@ package Net::BitTorrent::Torrent::Tracker::UDP;
     use lib q[../../../../../lib];
     use Net::BitTorrent::Util qw[:compact];
     use version qw[qv];
-    our $SVN = q[$Id: UDP.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $];
-    our $UNSTABLE_RELEASE = 2; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new((qw$Rev: 49 $)[1])->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
     my %REGISTRY = ();
     my @CONTENTS = \my (%_url,                  %_tier,
                         %_tid,                  %_cid,
@@ -398,7 +397,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -414,6 +413,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: UDP.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $
+=for svn $Id: UDP.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
 
 =cut
