@@ -4,8 +4,7 @@ package Net::BitTorrent::Version;
     use strict;
     use warnings;
     use version qw[qv];
-    our $SVN = q[$Id: Version.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $];
-    our $VERSION_BASE = 49; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
+    our $VERSION_BASE = 50; our $UNSTABLE_RELEASE = 0; our $VERSION = sprintf(($UNSTABLE_RELEASE ? q[%.3f_%03d] : q[%.3f]), (version->new(($VERSION_BASE))->numify / 1000), $UNSTABLE_RELEASE);
     our $PRODUCT_TOKEN = qq[Net::BitTorrent $VERSION];
 
     sub gen_peerid {
@@ -74,18 +73,18 @@ L<header|/Header> which may be used to identify the software and its
 version, and the L<signature|/Signature> which is... well, it's junk.
 Consider this example:
 
- NB004S-rogzGB1v--SVN
+ NB004S-rogzGB1v--git
 
-Here, C<NB004S> is the header and C<-rogzGB1v--SVN> is the trailing
+Here, C<NB004S> is the header and C<-rogzGB1v--git> is the trailing
 signature.
 
 =head3 Header
 
 The header consists of two uppercase characters ('C<NB>') followed by
-three digits (with leading zeros) representing the SVN revision, and a
-single character used to (potentially) indicate stability: C<S>table or
-C<U>nstable.  Any deviation from this indicates a bad client.  Recent
-stable builds will be found on CPAN.
+three digits (with leading zeros) representing the distribution version
+and a single character used to (potentially) indicate stability:
+C<S>table or C<U>nstable.  Any deviation from this indicates a bad
+client.  Recent stable builds will be found on CPAN.
 
 =head3 Signature
 
@@ -105,7 +104,7 @@ Distribution version numbers will be some value less than one (C<1>) with
 the revision number in the three significant decimal places.
 
 Recent stable builds will be found on CPAN.  Unstable builds will most
-likely be SVN checkouts and temporary uploads to CPAN where the package
+likely be private builds or temporary uploads to CPAN where the package
 name matches C<m[\d\.\d+_\d]>.  See the PAUSE FAQ section entitled
 "Developer Releases" (L<http://www.cpan.org/modules/04pause.html>).
 
@@ -113,9 +112,9 @@ name matches C<m[\d\.\d+_\d]>.  See the PAUSE FAQ section entitled
 
 =over
 
-=item C<NB393S-04.9EraQ--SVN>
+=item C<NB393S-04.9EraQ--git>
 
-This would be the stable CPAN release C<v0.393>/SVN r393.  The C<--SVN>
+This would be the stable CPAN-ready release C<v0.393>.  The C<--git>
 signature does not imply an unstable build.
 
 =item C<NB003X-9E-ayR6-IE<lt>3BT>
@@ -125,7 +124,7 @@ is a reserved character according to L<rfc: 3986|/"rfc3986">.
 
 =item C<NB065U--09Egae69sy8W>
 
-Completely legal Peer ID generated by unstable SVN/Dev r65.
+Completely legal Peer ID generated by unstable build around C<v65>.
 
 =back
 
@@ -145,7 +144,7 @@ http://slashdot.org/comments.pl?sid=997033&cid=25390887
 This document and the specification behind it are subject to change.
 All modifications will be documented in the Changes file included with
 this distribution.  All versions of this file can be found in the
-project's SVN repository.
+project's git repository.
 
 =head1 Author
 
@@ -155,7 +154,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -171,6 +170,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: Version.pm 49 2009-01-05 22:38:02Z sanko@cpan.org $
+=for svn $Id: Version.pm d8d71ee 2009-02-13 20:55:16Z sanko@cpan.org $
 
 =cut
