@@ -13,7 +13,7 @@ print map { qq[\n] . $_->path } @{$torrent->files};
 
 =head1 NAME
 
-/tatoeba/001-torrent-info.pl - Use Net::BitTorrent to gather information
+001-torrent-info.pl - Demonstration of using a standalone Net::BitTorrent::Torrent object to gather information
 
 =head1 Description
 
@@ -27,6 +27,8 @@ file.
 
 =head1 Lowdown
 
+This section only makes sense when you view the source.
+
 =over
 
 =item Line 6
@@ -73,7 +75,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -89,6 +91,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 001-torrent-info.pl 46 2008-12-30 23:25:17Z sanko@cpan.org $
+=for svn $Id: 001-torrent-info.pl 3f42870 2009-02-12 05:01:56Z sanko@cpan.org $
 
 =cut
