@@ -162,7 +162,7 @@ l q[Exiting];
 
 =head1 NAME
 
-/tatoeba/002-debug.pl - Logs EVERYTHING to a file for debugging
+002-debug.pl - Demonstration script that logs EVERYTHING
 
 =head1 Description
 
@@ -182,7 +182,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2008 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2008-2009 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of The Artistic License 2.0.  See the F<LICENSE>
@@ -198,6 +198,6 @@ clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 Neither this module nor the L<Author|/Author> is affiliated with
 BitTorrent, Inc.
 
-=for svn $Id: 002-debug.pl 49 2009-01-05 22:38:02Z sanko@cpan.org $
+=for svn $Id: 002-debug.pl 3f42870 2009-02-12 05:01:56Z sanko@cpan.org $
 
 =cut
